* **************************************************************************** *
* **************************************************************************** *
*           Combatting forest fires in the drylands of Sub-Saharan Africa:     *
*                Quas-experimental evidence from Burkina Faso                  *
* **************************************************************************** *
* **************************************************************************** *
/*
** PURPOSE:     Assembly and construction of final datasets
** IDS VAR:	    forerstid, forestBlockID, year
** WRITTEN BY:	Tung Nguyen Huy (nghuytungi@windowslive.com)
*/
**	OUTLINE:	PART 1: Reshape monthly dataset on forest fires, combine with additional data
**				PART 2: Reshape forest partition-level  dataset so that the unit of observation is forest parititon-year
** 				PART 3: Convert tree cover dataset and merge with forest fire dataset
**
* **************************************************************************** *
* **************************************************************************** *

* ------------------------------------------------------------------------------
* PART 1: Reshape monthly dataset on forest fires, combine with additional data
* ------------------------------------------------------------------------------
use "$RepPack_dtInt/burkina_faso_fires-MONTH_FOREST.dta", clear

	gen forestidYear = forestid * 10000 + year
	drop time
	
	// Normalize rounding errors for constant variables
	local LSMSvars	= "EstPop n_HH  avg_HH_size HH_educ* A5BIS mV07 "			///
					+ "A8* *_fert avg_dur_value L08_LightingW L14_CookingW " 	///
					+ "landIntFoodCons landIntFoodConsSh WoodFuelCons " 		///
					+ "B25A B25B B8_animiste distToSettl dist_aEdge distToRoad"
	
	foreach var of varlist	`LSMSvars'{
		bysort forestid year: egen `var'_median = median(`var')
		replace	`var' = `var'_median
		drop `var'_median
	}
	
	
	// Reshape dataset and re-applying variable labels
	local varsToReshape	= "fireBurn conf30 conf50 conf80 conf30_aE1000 conf30_aE2000 conf30Burn"
						
	foreach varx of local varsToReshape{
		local l`varx': variable label `varx'
	}
							
	reshape wide `varsToReshape', i(forestidYear) j(month)
	
	foreach varx of local varsToReshape{
		forvalues month=1/12{
			lab var	`varx'`month'		`"M`month' `l`varx''"'
		}
	}
	
	// Merge forest-year level fire setting and fire area data
	merge 1:1 year forestid using "${RepPack_dtInt}/burkina_faso_fires_firesetting_fullpanel_clean", keep(master match) nogen
	merge 1:1 year forestid using "${RepPack_dtInt}/climate.dta", keep(master match) nogen
	merge m:1 forestid using "${RepPack_dtInt}/forest_data.dta", keep(master match) nogen
	
	
	// Generate supporting variables and adjust outcomes for SCM optimization
	gen post2014Treatment	= (year >= 2014) * treatment
	gen post2015Treatment	= (year >= 2015) * treatment
	
	
	xtset forestid year
	drop if forestid>77
	
	lab var forestidYear		"Forest-year ID"
	lab var post2014Treatment	"Dummy if treated forest in the treatment period (starting from 2014)"
	lab var post2015Treatment	"Dummy if treated forest in the treatment period (starting from 2015)"
	
	order forestid forest_name year fip treatment 
	
save 	"$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", replace


copy "$RepPack_dtInt/burkina_faso_fires-MONTH_FOREST.dta" "$RepPack_dtFin/burkina_faso_fires-MONTH_FOREST.dta", replace




* -----------------------------------------------------------------------------
* PART 2: Reshape forest partition-level  dataset so that the unit of observation is forest parititon-year
* -----------------------------------------------------------------------------
use "$RepPack_dtInt/burkina_faso_fires_forestblock.dta", clear

	// Correct round errors in time invariant variables
	foreach var of varlist	dist_aEdge distToSettl gridid {
	    bysort forestBlockID year: 	egen 	`var'_median= mean(`var')
		bysort forestBlockID year: 	replace `var'		= round(`var'_median, .000001)
		
		drop `var'_median
	}
	
	// Define and save the labels of the variables to be reshaped; then reshape
	local varsToReshape	= " fire conf30 conf50 conf80 "				///
						+ "	fireBurn conf30Burn conf50Burn conf80Burn "	
	foreach varx of local varsToReshape{
		local l`varx':		variable label `varx'
	}
	
	drop time
	gen long forestBlockYear	= forestBlockID * 10000 + year 		//  Forest partition-year-level ID for reshaping 
	reshape wide `varsToReshape' , i(forestBlockYear) j(month)
	
	foreach varx of local varsToReshape {
	    forvalues month = 1/12 {
		    lab var `varx'`month'		`"M`month' `l`varx''"'
		}
	    
	}
	
	// Merge other data
	merge m:m OBJECTID using "$RepPack_dtInt/LSMS_vars.dta", keep(master match) nogen
	merge m:1 forestid using "$RepPack_dtInt/forest_data.dta", keep(master match) nogen
	merge m:1 forestid year using "$RepPack_dtInt/climate.dta", keep(master match) nogen
	
	// Generate panel treatment indicators
	gen post2014Treatment	= (year >= 2014) * treatment
	gen post2015Treatment	= (year >= 2015) * treatment
	
	lab var post2014Treatment	"Dummy if treated forest in the treatment period (starting from 2014)"
	lab var post2015Treatment	"Dummy if treated forest in the treatment period (starting from 2015)"
	
	xtset forestBlockID year, yearly
	order forestid forestBlockID year fip treatment 
	
	save "$RepPack_dtFin/burkina_faso_fires_forestblock-YEAR.dta" , replace
	
	
	
* -----------------------------------------------------------------------------
* PART 3: Convert tree cover dataset and merge with forest fire dataset
* -----------------------------------------------------------------------------
use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear
	
	merge 1:1 year forestid using "$RepPack_dtInt/BF_forests_treecoverpanel.dta", ///
		keepusing(treecover) keep(master match) gen(_mergeTcover)
		
	drop if forestid>77
		
	save "$RepPack_dtFin/burkina_faso_fires_tcover-YEAR_FOREST.dta", replace
	